
#ifndef _C146_ds7299_
#define _C146_ds7299_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F6437_87229(EIF_REFERENCE);
extern void EIF_Minit7299(void);

#ifdef __cplusplus
}
#endif

#endif
